@@ -1,16 +1,40 @@
 #%%
+from itertools import chain
+from collections import Counter
 from dcctk.corpusReader import PlainTextReader
-from dcctk.concordancer import Concordancer
-# from dcctk.corpus import IndexedCorpus
+# from dcctk.concordancer import Concordancer
+# from dcctk.corpus import NgramCorpus, Gsq, DeltaP12, DeltaP21
 # from dcctk.dispersion import Dispersion
 # from dcctk.compoAnalysis import CompoAnalysis
 # from dcctk.compoConcordancer import CompoConcordancer
 # from dcctk.embeddings import AnchiBert
+corp_reader = PlainTextReader('data/', auto_load=False)
 
+c = (c for sc in corp_reader.get_corpus_as_gen() for t in sc['text'] for c in t['c'])
+fq_dist = Counter(chain.from_iterable(c))
+# for i, ch in enumerate(chain.from_iterable(c)):
+#     if i == 5: break
+#     print(ch)
+#%%
+
+corp_reader = PlainTextReader('data2/', auto_load=False)
+NC = NgramCorpus(corp_reader)
+NC.load()
+# NC._count_ngrams(2)
+# Custom association measures
+NC.association_measures = [Gsq, DeltaP12, DeltaP21]
+NC.bigram_associations(fq_thresh=10)
+
+#%%
+bi_asso = NC.bigram_associations()
+#%%
+for i, x in enumerate(NC.bigram_associations_gen()):
+    if i == 5: break
+    print(x)
 # c = Dispersion(PlainTextReader("data/").corpus)
 
 # c = TextBasedCorpus(PlainTextReader("data/").corpus)
-c = Concordancer(PlainTextReader("data/").corpus)
+# c = Concordancer(PlainTextReader("data/").corpus)
 #%%
 cql = """
 "夫" "妻"
